@@ -112,6 +112,7 @@ gbTarget.prototype.initByXML = function(x){
 gbTarget.prototype.updateByParamStr = function(paramStr)
 {
 	var params = paramStr.split("_");
+//	this.coord = unescape(params[0]);
 	this.coord = params[0];
 	this.position = new gbPosition(
 			params[1],
@@ -125,7 +126,8 @@ gbTarget.prototype.updateByParamStr = function(paramStr)
 
 gbTarget.prototype.toQuery = function()
 {
-	return "" + escape(this.coord) + "_" + this.position.toQuery();
+//	return "" + escape(this.coord) + "_" + this.position.toQuery();
+	return "" + this.coord + "_" + this.position.toQuery();
 }
 
 function gbObj()
@@ -290,6 +292,7 @@ gbLayer.prototype.updateByParams = function(params){
 		}
 	}
 	this.setVisible(v);
+	return v;
 }
 
 
@@ -332,7 +335,9 @@ gbLayerGroup.prototype.initByXML = function(layerGroupXML)
 		this.id = id;
 	}
 	
-	this.visible = layerGroupXML.getAttribute("visible")=="false" ? false : true;
+	this.visible = layerGroupXML.getAttribute("visible")!="false";
+	this.expand = layerGroupXML.getAttribute("expand")!="false";
+	
 	this.xml = layerGroupXML;
 	
 	var children = layerGroupXML.childNodes;
@@ -397,8 +402,11 @@ gbLayerGroup.prototype.updateByParams = function(params){
 	}
 	this.setVisible(v);
 	for(var i=0; i<this.layers.length; ++i){
-		this.layers[i].updateByParams(params);
+		if(this.layers[i].updateByParams(params)){
+			this.expand = true;
+		}
 	}
+	return v;
 }
 
 
